@@ -1,9 +1,7 @@
 use strict;
 use warnings;
 package Mojolicious::Plugin::Database;
-{
-  $Mojolicious::Plugin::Database::VERSION = '1.08';
-}
+$Mojolicious::Plugin::Database::VERSION = '1.09';
 use Mojo::Base 'Mojolicious::Plugin';
 use DBI;
 
@@ -16,10 +14,15 @@ sub single {
 
     my $dbh_connect = sub { DBI->connect($conf->{dsn}, $conf->{username}, $conf->{password}, $conf->{options}) };
 
-    $app->attr('dbh' => $dbh_connect);
-
     my $helper_name = $conf->{helper} || 'db';
-    $app->helper($helper_name => sub { return shift->app->dbh });
+
+    $app->attr("_dbh_$helper_name" => $dbh_connect);
+
+    $app->helper($helper_name => sub { 
+        my $self = shift;
+        my $attr = "_dbh_$helper_name";
+        return $self->app->$attr();
+    });
 }
 
 sub multi {
@@ -63,7 +66,7 @@ Mojolicious::Plugin::Database - "proper" handling of DBI based connections in Mo
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =head1 SYNOPSIS
 
@@ -180,7 +183,7 @@ Babatope Aloba for pointing out it'd be really useful to be able to connect to m
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011, 2012 Ben van Staveren.
+Copyright 2011-2015 Ben van Staveren.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
